#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

# ***************************************************************************
#    copyright            : (C) 2006 by Mathias Monnerville
#    email                : tellico_dev@yahoo.fr
#  	copyright			 : (C) 2007 by Raphal Fischer
#	email			 : fischer.tellico@free.fr
# ***************************************************************************
#	You are welcome to report any bug to Raphal Fischer, such as missing or wrong information, when comparing to trictrac.net.
# ***************************************************************************
# *                                                                         *
#This file is part of trictrac.net.py.

    #trictrac.net.py is free software: you can redistribute it and/or modify
    #it under the terms of the GNU General Public License as published by
    #the Free Software Foundation, either version 3 of the License, or
    #(at your option) any later version.

    #trictrac.net.py is distributed in the hope that it will be useful,
    #but WITHOUT ANY WARRANTY; without even the implied warranty of
    #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    #GNU General Public License for more details.

    #You should have received a copy of the GNU General Public License
    #along with trictrac.net.py.  If not, see <http://www.gnu.org/licenses/>.

# *                                                                         *
# ***************************************************************************

# $Id: trictrac.net 123 2007-08-09 raphael $

"""
This script is based on other tellico scripts due to Mathias Monnerville. They were modified and extended to get as much information as possible on the trictrac.net data base.
You are welcome to report any bug to Raphal Fischer, such as missing or wrong information, when comparing to trictrac.net.

This script is meant to be used with tellico (http://periapsis.org/tellico) as an external data source program.
It allows searching through the trictrac.net web database.

Related info and cover are fetched automatically. It takes two arguments : exact title, or keyword.

Tellico data source setup:
- source name: Trictrac (or whatever you want :)
- Collection type: custom collection
- Result type: tellico
- Path: /path/to/script/trictrac.net.py
- Arguments:
Title (checked) = -e %1
Keyword (checked) = -t %1

Update will be taken into account once Tellico allow the use of update for custom collection.
"""

import sys, os, re, md5, random, string
import urllib, urllib2, time, base64
import xml.dom.minidom

XML_HEADER = """<?xml version="1.0" encoding="UTF-8"?>"""
DOCTYPE = """<!DOCTYPE tellico PUBLIC "-//Robby Stephenson/DTD Tellico V9.0//EN" "http://periapsis.org/tellico/dtd/v9/tellico.dtd">"""
NULLSTRING = ''

VERSION = "0.2"
	
	 
def genMD5():
	"""
	Generates and returns a random md5 string. Its main purpose is to allow random 
	image file name generation.
	"""
	obj = md5.new()
	float = random.random()
	obj.update(str(float))
	return obj.hexdigest()

class BasicTellicoDOM:
	"""
	This class manages tellico's XML data model (DOM)
	"""
	def __init__(self):
		self.__dict = {'' : '&Aacute;', '' : '&aacute;', '' : '&Acirc;', '' : '&acirc;', '' : '&Agrave;', '' : '&agrave;', '' : '&Aring;',  '' : '&aring;',  '' : '&Atilde;', '' : '&atilde;', '' : '&Auml;', '' : '&auml;', '' : '&acute;', '' : '&AElig;', '' : '&aelig;', '' : '&brvbar;', '' : '&Ccedil;', '' : '&ccedil;', '' : '&cedil;', '' : '&raquo;', '' : '&laquo;', '' : '&copy;', '' : '&sup2;', '' : '&Eacute;', '' : '&eacute;', '' : '&Ecirc;', '' : '&ecirc;', '' : '&Egrave;', '' : '&egrave;', '' : '&Euml;','' : '&euml;',' ' : '&nbsp;','&' : '&amp;','' : '&ETH;','' : '&eth;','' : '&iexcl;', '' : '&frac34;', '' : '&frac12;', '' : '&frac14;',  '' : '&Iacute;', '' : '&iacute;', '' : '&Icirc;',  '' : '&icirc;', '' : '&Igrave;', '' : '&igrave;', '' : '&Iuml;', '' : '&iuml;', '<' : '&lt;', '' : '&macr;', '' : '&reg;', '' : '&Ntilde;', '' : '&ntilde;', '' : '&Oacute;', '' : '&oacute;', '' : '&Ocirc;', '' : '&ocirc;',  '' : '&Ograve;','' : '&ograve;', '' : '&Oslash;','' : '&oslash;', '' : '&Otilde;', '' : '&otilde;', '' : '&Ouml;', '' : '&ouml;', '' : '&ordf;', '' : '&ordm;', '' : '&plusmn;', '' : '&iquest;', '' : '&middot;', '' : '&szlig;',  '' : '&deg;', '' : '&divide;', '' : '&micro;',  '' : '&times;', '' : '&not;', '' : '&para;', '' : '&sect;', '' : '&yen;', '>' : '&gt;', '' : '&cent;', '' : '&pound;', '' : '&curren;', '' : '&THORN;', '' : '&thorn;', '' : '&uml;', '' : '&sup3;', '' : '&Uacute;', '' : '&uacute;', '' : '&Ucirc;',  '' : '&ucirc;', '' : '&Ugrave;', '' : '&ugrave;', '' : '&Uuml;', '' : '&uuml;','' : '&sup1;','' : '&Yacute;', '' : '&yacute;', '' : '&yuml;'}

		self.__doc = xml.dom.minidom.Document()
		self.__root = self.__doc.createElement('tellico')
		self.__root.setAttribute('xmlns', 'http://periapsis.org/tellico/')
		self.__root.setAttribute('syntaxVersion', '9')
		
		self.__collection = self.__doc.createElement('collection')
		self.__collection.setAttribute('title', 'Jeux de plateau')
		self.__collection.setAttribute('type', '1')

		self.__fields = self.__doc.createElement('fields')
		# Add all default (standard) fields
		self.__dfltField = self.__doc.createElement('field')
		self.__dfltField.setAttribute('name', '_default')
		self.__fields.appendChild(self.__dfltField)
  		self.newField(field={'flags' : '8', 'title' : 'Titre', 'category' : 'Gnral', 'format': '1', 'type': '1', 'name': 'title'})
		self.newField(field={'flags':'0', 'title':'Nom VO', 'category':'Gnral', 'format':'1', 'type':'1', 'name':'nomvo'})
   		self.newField(field={'flags':'3', 'title':'Auteur', 'category':'Gnral', 'format':'2', 'type':'1', 'name':'auteur'})
   		self.newField(field={'flags':'3', 'title':'Illustrateur', 'category':'Gnral', 'format':'2', 'type':'1', 'name':'illustrateur'})
   		self.newField(field={'flags':'1', 'title':'Editeur', 'category':'Publication', 'format':'4', 'type':'1', 'name':'editeur'})
    		self.newField(field={'flags':'1', 'title':'Distributeur', 'category':'Publication', 'format':'4', 'type':'1', 'name':'distributeur'})
   		self.newField(field={'flags':'1', 'title':'Collection', 'category':'Publication', 'format':'4', 'type':'1', 'name':'collection'})
   		self.newField(field={'flags':'1', 'title':'Origine', 'category':'Publication', 'format':'0', 'type':'1', 'name':'origine'})
   		self.newField(field={'flags':'2', 'title':'Anne', 'category':'Publication', 'format':'4', 'type':'6', 'name':'annee', 'description':'Anne de publication'})
  		self.newField(field={'flags':'3', 'title':'Genre', 'category':'Classification', 'format':'4', 'type':'1', 'name':'genre'})
  		self.newField(field={'flags':'3', 'title':'Famille', 'category':'Classification', 'format':'4', 'type':'1', 'name':'famille'})
  		self.newField(field={'flags':'3', 'title':'Mcanisme', 'category':'Classification', 'format':'4', 'type':'1', 'name':'mecanisme'})
  		self.newField(field={'flags':'3', 'title':'Thme', 'category':'Classification', 'format':'4', 'type':'1', 'name':'theme'})
  		self.newField(field={'flags':'2', 'title':'Joueurs', 'category':'Gnral', 'format':'4', 'type':'1', 'name':'joueurs', 'description':"Nombre de joueurs"})
 		self.newField(field={'flags':'0', 'title':'Dure', 'category':'Gnral', 'format':'4', 'type':'1', 'name':'duree'})
		self.newField(field={'flags':'2', 'title':'Age min.', 'category':'Gnral', 'format':'4', 'type':'6', 'name':'age'})
  		self.newField(field={'flags':'0', 'title':'Prix', 'category':'Publication', 'format':'4', 'type':'1', 'name':'prix'})
  		self.newField(field={'flags':'0', 'title':'Disponibilit', 'category':'Classification', 'format':'4', 'type':'1', 'name':'disponibilite'})
  		self.newField(field={'flags':'0', 'title':'Rgle', 'category':'Publication', 'format':'4', 'type':'1', 'name':'regle'})
		self.newFieldNote(Vmin=0, Vmax=5, field={'flags':'0', 'title':'Difficult', 'category':'Gnral', 'format':'4', 'type':'14', 'name':'difficulte'})
 		self.newFieldNote(Vmin=0, Vmax=5, field={'flags':'0', 'title':'Chance', 'category':'Gnral', 'format':'4', 'type':'14', 'name':'chance'})
		self.newFieldNote(Vmin=0, Vmax=5, field={'flags':'0', 'title':'Stratgie', 'category':'Gnral', 'format':'4', 'type':'14', 'name':'strategie'})
		self.newFieldNote(Vmin=0, Vmax=5, field={'flags':'0', 'title':'Diplomatie', 'category':'Gnral', 'format':'4', 'type':'14', 'name':'diplomatie'})
		self.newFieldNote(Vmin=0, Vmax=10, field={'flags':'0', 'title':'Avis des joueurs', 'category':'Classification', 'format':'4', 'type':'14', 'name':'avisjoueurs'})
		self.newField(field={'flags':'0', 'title':'Fiche TricTrac', 'category':'Classification', 'format':'4', 'type':'6', 'name':'numero'})
		self.newField(field={'flags':'0', 'title':'Commentaires', 'category':'Commentaires', 'format':'4', 'type':'2', 'name':'commentaire'})
		self.newField(field={'flags':"0", 'title':"Image", 'category':"Image", 'format':"4", 'type':"10", 'name':"image", 'description':"Image du jeu"})
		self.__images = self.__doc.createElement('images')
		self.__root.appendChild(self.__collection)
		self.__doc.appendChild(self.__root)

		# Current movie id. See entry's id attribute in self.addEntry()
		self.__currentId = 0

	def newFieldNote(self,Vmin,Vmax,field):
		self.__customField = self.__doc.createElement('field')
		for item, value in field.iteritems():
			self.__customField.setAttribute(item, unicode(value, 'latin-1').encode('utf-8'))
		minNode = self.__doc.createElement('prop')
		minNode.setAttribute('name', 'minimum')
		minNode.appendChild(self.__doc.createTextNode('%s' % Vmin))
		self.__customField.appendChild(minNode)
		maxNode = self.__doc.createElement('prop')
		maxNode.setAttribute('name', 'maximum')
		maxNode.appendChild(self.__doc.createTextNode('%s' % Vmax))
		self.__customField.appendChild(maxNode)
		self.__fields.appendChild(self.__customField)
		self.__collection.appendChild(self.__fields)
		
	def newField(self,field):
		self.__customField = self.__doc.createElement('field')
		for item, value in field.iteritems():
			self.__customField.setAttribute(item, unicode(value, 'latin-1').encode('utf-8'))
		self.__fields.appendChild(self.__customField)
		self.__collection.appendChild(self.__fields)

	def html2utf(self,chaine):
		for vers,de in self.__dict.iteritems():	
			chaine=re.sub(de, vers, chaine)
		chaine=unicode(chaine, 'latin-1').encode('utf-8')
		return chaine
		
	def addEntry(self, jeuData):
		"""
		Add a comic entry. 
		Returns an entry node instance
		"""
		d = jeuData
		entryNode = self.__doc.createElement('entry')
		entryNode.setAttribute('id', str(self.__currentId))
		fields=['title', 'nomvo', 'auteur', 'illustrateur', 'editeur', 'distributeur', 'collection', 'origine', 'annee', 'genre', 'famille', 'mecanisme', 'theme', 'joueurs', 'age', 'duree', 'prix', 'disponibilite', 'regle', 'difficulte', 'chance', 'strategie', 'diplomatie',  'avisjoueurs', 'numero', 'commentaire']
		if d['image']:
			imageNode = self.__doc.createElement('image')
			imageNode.setAttribute('format', 'JPEG')
			imageNode.setAttribute('id', d['image'][0])
			imageNode.appendChild(self.__doc.createTextNode(unicode(d['image'][1], 'latin-1').encode('utf-8')))
			coverNode = self.__doc.createElement('image')
			coverNode.appendChild(self.__doc.createTextNode(d['image'][0]))
		for name in fields:
			Node=self.__doc.createElement(name)
			try:
				if d[name] in ['.--','--','nc']:
					Node.appendChild(self.__doc.createTextNode(''))
				else:
					Node.appendChild(self.__doc.createTextNode(self.html2utf(d[name])))
			except:
				Node.appendChild(self.__doc.createTextNode(''))
			entryNode.appendChild(Node)
		if d['image']:
			entryNode.appendChild(coverNode)
			self.__images.appendChild(imageNode)
		self.__collection.appendChild(entryNode)
		self.__currentId += 1
		return entryNode

	def printEntry(self, nEntry):
		"""
		Prints entry's XML content to stdout
		"""
		try:
			print nEntry.toxml()
		except:
			print sys.stderr, "Error while outputing XML content from entry to Tellico"

	def printXMLTree(self):
		"""
		Outputs XML content to stdout
		"""
		self.__collection.appendChild(self.__images)
		print XML_HEADER; print DOCTYPE
		print self.__root.toxml()


class TrictracParser:	
	def __init__(self):
		self.__baseURL 	 = 'http://www.trictrac.net'
		self.__basePath  = '/'
		self.__searchURL = '/index.php3?id=jeux&rub=ludotheque&inf=cat&nb=200&choix=%s'
		self.__coverPath = '/jeux/centre/imagerie/boites/'
		self.__serieURL  = self.__baseURL + self.__basePath

		# Define some regexps
		self.speciaux=['^', '.', '[', ']', '$', '(', ')', '*', '+', '?', '|', '{', '}', '\\']
		
		self.__dict={'[]' : 'a',
				 '[]' : 'ae',
				 '[]' : 'c',
				 '[]' : 'e',
				 '[]' : 'd',
				 '[]' : 'o',
				 '[]' : 'i',
				 '[]' : 'r',
				 '[]' : 'n',
				 '[]' : 'u',
				 '[]' : 'y'}
				 
		self.__dict2={'<[^>]*>' : '', '\t': '', '<br [^>]*>' : '\n'}
			
		self.__regExps = {'title' : """<table width="520" border="0" align="center" cellpadding="0" cellspacing="2">[^<]*<tr>[^<]*<td colspan="2"><font style='COLOR: #004B56; FONT-FAMILY: arial; FONT-SIZE: 20px; font-weight: BOLD'><i>([^<]*)</i></td>[^<]*</tr>""",
			'nomvo': """<font style='COLOR: #000000; FONT-FAMILY: arial; FONT-SIZE: 12px;'>Nom VO : ([^<]*)</b>""",
			'notes' : "<img src='/jeux/centre/imagerie/barre_([0-9]*)\.gif' ></TD>", 
			'avisjoueurs' : """<font[^>]*> Moyenne  : ([0-9]\.[0-9]*)<font[^>]*><br>""",
					# On va jusqu'au bout du fichier, on coupera plus tard
				}
		self.__ReBlocs={'autresinfos' : ["""<TABLE [^>]*>[^<]*<TR>[^<]*<TD VALIGN="TOP" WIDTH="100"><DIV ALIGN="RIGHT">[^<]*<font [^>]*>[^<]*<FONT COLOR="#999999">(Auteur\(s\) :</FONT> </DIV></TD>)""", '</TABLE>'],
					'commentaire' : ["""<DIV ALIGN="LEFT"><FONT[^>]*><B><FONT SIZE="3"><I><FONT[^>]*>Description</FONT></I></FONT></B></FONT>[^<]*</DIV>[^<]*</TD>[^<]*</TR>[^<]*<TR>[^<]*<TD><IMG SRC="/jeux/imagerie/separateur_v_l.gif" WIDTH="470" HEIGHT="1"></TD>[^<]*</TR>[^<]*<TR>[^<]*<TD[^>]*>[^<]*<TABLE[^>]*>[^<]*<TR BGCOLOR="#FFFFFF">[^<]*<TD>[^<]*<DIV ALIGN="left">[^<]*<p font style='COLOR: #000000; FONT-FAMILY: arial; FONT-SIZE: 12px; TEXT-ALIGN: justify;'>(.*)""" , """</TD>[^<]*</TR>[^<]*</TABLE>"""]}
								
		self.__regExpTxt=[['auteur', 'Auteur\(s\) :'],
					['illustrateur', 'Illustrateur\(s\) :'],
					['editeur', 'Editeur :'],
					['distributeur', 'Distributeur :'], 
					['collection', 'Collection :'],
					['origine', 'Origine :'], 
					['annee', 'Ann&eacute;e :'], 
					['genre', 'Genre\(s\) :'], 
					['famille', 'Famille\(s\) :'], 
					['mecanisme', 'M&eacute;canisme\(s\) :'], 
					['theme', 'Th&egrave;me\(s\) :'], 
					['joueurs', 'Joueurs :'], 
					['age', 'Age :'], 
					['duree', 'Dur&eacute;e :'],
					['prix', 'prix constat&eacute; :'], 
					['disponibilite', 'disponibilit&eacute; :'], 
					['regle', 'r&egrave;gle :'],
					['fin', '']
					]

		# Compile patterns objects
		self.__regExpsPO = {}
		for k, pattern in self.__regExps.iteritems():
			self.__regExpsPO[k] = re.compile(pattern,18)		

		self.__regExpTxtPO = {}
		for a in range(len(self.__regExpTxt)-1):
			name=self.__regExpTxt[a][0]
			re1=self.__regExpTxt[a][1]
			re2=self.__regExpTxt[a+1][1]
			self.__regExpTxtPO[name] = re.compile('%s[ ;]*(.*)%s' % (re1,re2),18)
			
		self.__BlocsPO = {}
		for k, regex in self.__ReBlocs.iteritems():
			self.__BlocsPO[k] =  (re.compile(regex[0],18),re.compile(regex[1],18))
		self.__count = 0
		self.__domTree = BasicTellicoDOM()


	def __fetchCover(self, path, delete = True):
		"""
		Fetch cover to /tmp. Returns base64 encoding of data.
		The image is deleted if delete is True
		"""
		md5 = genMD5()
		imObj = urllib2.urlopen(path.strip())
		img = imObj.read()
		imObj.close()
		imgPath = "/tmp/%s.jpeg" % md5
		try:
			f = open(imgPath, 'w')
			f.write(img)
			f.close()
		except:
			print sys.stderr, "Error: could not write image into /tmp"

		b64data = (md5 + '.jpeg', base64.encodestring(img))

		# Delete temporary image
		if delete:
			try:
				os.remove(imgPath)
			except:
				print sys.stderr, "Error: could not delete temporary image /tmp/%s.jpeg" % md5
		return b64data

	def __FetchGameInfo(self,numero,page):
		# First grab picture data
		imgPath = self.__baseURL + self.__coverPath + numero + "_0.jpg"
		b64img = self.__fetchCover(imgPath)
		#Certaines infos sont plus faciles  obtenir  partir du code html, et d'autres moins
		# Dans le deuxime cas, on enlve toutes les balises <...>
		matches = {}
		data = {}
		# Default values
		data['image'] 		= b64img
		data['numero']	= numero
		# Infos extraites du HTML
		#print numero
		for name, po in self.__regExpsPO.iteritems():
			
			matches[name] = po.findall(page)
			if matches[name]:
				if name== 'notes' and len(matches[name])==4:
					data['difficulte']=matches[name][0]
					data['chance']=matches[name][1]
					data['strategie']=matches[name][2]
					data['diplomatie']=matches[name][3]
				elif name == 'avisjoueurs':
					try: 	
						data[name]=str(round(2*float(matches[name][0])))
					except:
						data[name]= NULLSTRING	
				else:
					data[name] = NULLSTRING	
					for item in matches[name]:
						if len(data[name])>0:
							data[name] += ";"+item
						else:
							data[name] = item
			else:
				data[name] = NULLSTRING
		# Extraction des blocs d'infos
		for bloc, po2 in self.__BlocsPO.iteritems():
			data[bloc]=NULLSTRING
			decoupe = po2[0].search(page)
			if decoupe:
				souspage=page[decoupe.start(1):]
				decoupe = po2[1].search(souspage)
				if decoupe:
					souspage=souspage[:decoupe.start(0)]
					if bloc=='commentaire':
						for balise in ['[aA]', 'div','DIV','[tT][dDrRhH]','font','FONT','img','IMG','TABLE','table','CENTER','center']:
							souspage=re.sub('< *%s[^>]*>' % balise,'',souspage)
							souspage=re.sub('</ *%s[^>]*>' % balise,'',souspage)
						for char in ['\n','\r']:					
							souspage=re.sub(char,'',souspage)
						data[bloc]=souspage
					else:
						souspage=re.sub('\n','',souspage)
						souspage=re.sub('<[Aa][^>]*>',';',souspage)
						souspage=re.sub('<[^>]*>','',souspage)
						souspage=re.sub(' (?= )','',souspage)
						
						for name, PO in self.__regExpTxtPO.iteritems():
							res=PO.search(souspage).group(1)
							data[name]=re.sub(' $','',res)
							if name=="age":
								res=re.search('([0-9]*) &agrave;.*',data[name],18)
								if res:
									data[name]=res.group(1)
								else:
									data[name]=''
		return data				

	def __fetchLinks(self,motif):
		matchList = re.findall(motif, self.__data,18)
		#print matchList
		if not matchList: return None
		return matchList

	def __getGame(self):
		# On commence par faire une liste des sries  traiter, que l'on cherche par auteur ou titre
		self.__count2=0
		if self.__exact:
			self.__getHTMLContent("%s%s&exclu=titre" % (self.__baseURL, self.__searchURL % urllib.quote(self.__title)))
		else:
			self.__getHTMLContent("%s%s" % (self.__baseURL, self.__searchURL % urllib.quote(self.__title)))
			
		# Est-on arriv  un jeu ou  un choix de jeu ?
		
		if not re.match('.*voir la fiche',self.__data,18):
			#print "On est tomb directement sur la page du jeu, pas la peine de recharger"
			if re.match("Aucun jeu correspondant  votre demande n'est actuellement dans notre ludothque.",self.__data,18):
			
				return None
			try:
				numero=re.search("<img src='/jeux/centre/imagerie/boites/([0-9]*)_[0-9]\.jpg' border=1>",self.__data).group(1)
			except:
				return None
			links=[('unique', numero)]
			
		else: # On fait la liste des jeux de la page
			links=self.__fetchLinks("""<TD><IMG SRC="/jeux/imagerie/fleche_d\.gif" WIDTH="6" HEIGHT="8"><a href='(index\.php3\?id=jeux&rub=detail&inf=detail&jeu=([0-9]*))'><font style='COLOR: #000000; FONT-FAMILY: arial; FONT-SIZE: 12px;'> Voir la fiche</a></TD>""")
		
		# On a selectionn les sries, on recherche les albums :
		#print links
		if links:
			for url, numero in links:
				#print url,numero
				if not url=='unique':
					self.__getHTMLContent("%sindex.php3?id=jeux&rub=detail&inf=detail&jeu=%s" % (self.__serieURL,numero))
		
				data=self.__FetchGameInfo(numero,self.__data)
				node = self.__domTree.addEntry(data)
				self.__count+=1
		else:
			return None
		
	def __getcritique(self, url):
		u = urllib2.urlopen(url)
		critique = u.read()
		u.close()
		chro2=re.search(self.__chronique['texte'],critique,18).group(1).split("Votre avis nous intresse")[0]
		chro2=self.html2txt(chro2)
		#print chro2
		return "<br/><b>Chronique : </b>%s" % chro2
	
	def slash(self, expr):
		for de in self.speciaux:
			expr=re.sub('\\'+de,'\\'+de,expr)
		return expr

	def IsNameIn(self,search,str1):
		if len(str1)==0:
			return 0==1
		if len(search)==0:
			return 1==1
		for de, vers in self.__dict.iteritems():	
			str1=re.sub(de, vers, str1)
			search=re.sub(de, vers, search)
		ok=1
		str1=re.sub('-',' ',str1)
		mots1=re.sub(',','',str1).split(' ')		
		mots2=search.split(' ')	
		for mot2 in mots2:
			ok2=0
			for mot1 in mots1:
				if re.match(".*"+mot1,mot2,18):
					ok2=1
			ok*=ok2
		return ok==1
		
	def IsAuteurIn(self,str1):
		if len(str1)==0:
			return 0==1
		for de, vers in self.__dict.iteritems():	
			str1=re.sub(de, vers, str1)
		mots2=self.__author.split(' ')
		ok=1 
		for mot2 in mots2:
			if not re.match(".*"+mot2,str1,18):
				ok=0
		return ok==1


	def IsTitleIn(self,title,str2):
		#str2=unicode(str2, 'latin-1').encode('utf-8')
		#print "%s %s" % (title,str2)
		for de, vers in self.__dict.iteritems():	
			str2=re.sub(de, vers, str2)
		return re.match(".*"+title,str2,18)

	def html2txt(self,chaine):
		for de, vers in self.__dict2.iteritems():	
			chaine=re.sub(de, vers, chaine)
		return chaine


	def __getHTMLContent(self, url):
		"""	Fetch HTML data from url	"""
		#print url
		u = urllib2.urlopen(url)
		self.__data = u.read()
		u.close()
		self.__count2+=1
	
	def run(self,title,exact):
		self.__title=title
		self.__exact=exact
		self.__getGame()
		# Print results to stdout
		self.__domTree.printXMLTree()
		print unicode("<!--\tRecherche de : %s\n%s jeux trouvs, et %s pages explores-->" % (self.__title, self.__count, self.__count2), 'latin-1').encode('utf-8')
		

def halt():
	#print "HALT."
	sys.exit(0)

def showUsage():
	print """Usage: trictrac.net.py options 
Options : 
	-t "game's name" 
	-e "exact name"
"""
		
	sys.exit(1)

def main():
	
	if len(sys.argv) < 2:
		showUsage()
		
	parser = TrictracParser()
	parser.run(sys.argv[2],sys.argv[1]=='-e')
	
if __name__ == '__main__':
	main()
